# streamlit-luckysheet

2024 Aug 18 First Ever Streamlit luckysheet.
Credit To TAN YIHAO

## Installation instructions

```sh
pip install streamlit-luckysheet
```

## Usage instructions

```python
import streamlit as st
from streamlit_luckysheet import streamlit_luckysheet

st.set_page_config(layout="wide")
st.subheader("Component with constant args")

result = streamlit_luckysheet(None)


```
